<?php

/**
 * @file
 * Helper functions for the Important Information module.
 *
 * Use module_load_include('inc', 'important_information',
 * 'important_information')
 * to use these functions within another module.
 *
 * @ingroup important_information
 */

/**
 * Get important information settings.
 */
function _important_information_get_settings() {
  $iiBody = variable_get('important_information__body', array('value' => '', 'format' => NULL));
  return array(
    'title' => variable_get('important_information__title', 'Important Information'),
    'body' => $iiBody['value'],
    'position' => variable_get('important_information__position', 'right'),
    'mobile_position' => variable_get('important_information__mobile_position', 'top'),
    'mobile_breakpoint' => variable_get('important_information__mobile_breakpoint', '768px'),
    'size' => variable_get('important_information__size', '300px'),
    'mobile_size' => variable_get('important_information__mobile_size', '300px'),
    'inner_spacing' => variable_get('important_information__inner_spacing', '10'),
    'outer_spacing' => variable_get('important_information__outer_spacing', '10'),
    'body_spacing_type' => variable_get('important_information__body_spacing_type', 'margin'),
    'enable_dismiss' => variable_get('important_information__enable_dismiss', 0),
    'enable_full_screen' => variable_get('important_information__enable_full_screen', 0),
    'top_background_color' => variable_get('important_information__top_background_color', 'white'),
    'body_background_color' => variable_get('important_information__body_background_color', 'white'),
    'border_color' => variable_get('important_information__border_color', '#ccc'),
    'border_style' => variable_get('important_information__border_style', 'solid'),
    'border_width' => variable_get('important_information__border_width', '1'),
    'headings_color' => variable_get('important_information__headings_color', '#0282a5'),
    'headings_font_family' => variable_get('important_information__headings_font_family', 'Sans Serif'),
    'headings_main_font_size' => variable_get('important_information__headings_main_font_size', '20px'),
    'headings_secondary_font_size' => variable_get('important_information__headings_secondary_font_size', '18px'),
    'body_font_color' => variable_get('important_information__body_font_color', '#000000'),
    'body_font_family' => variable_get('important_information__body_font_family', 'Sans Serif'),
    'body_font_size' => variable_get('important_information__body_font_size', '16px'),
  );
}

/**
 * Generate custom CSS.
 */
function _important_information_css($settings) {
  // Variables.
  $section_class = '.block-important-information .important-information';
  $body_class = "body.has-important-information.ii-{$settings['position']}";
  // Mixins.
  $border_style = _important_information_border_css($settings);
  $headings_styles = _important_information_headings_css($settings, $section_class);
  $block_body_styles = _important_information_block_body_css($settings, $section_class);
  $color_styles = _important_information_color_css($settings, $section_class);
  // Positioning.
  $positioning_styles = _important_information_positioning_css($settings, $body_class, $section_class);
  $mobile_positioning_styles = _important_information_mobile_positioning_css($settings, $body_class, $section_class);
  // Spacing.
  $spacing_styles = _important_information_spacing_css($settings, $section_class);
  // CSS.
  $css = <<<EOT
  $headings_styles
  $section_class { $border_style }
  $spacing_styles
  $block_body_styles
  $color_styles
  $positioning_styles
  $mobile_positioning_styles
EOT;
  return $css;
}

/**
 * Generate custom borders CSS.
 */
function _important_information_border_css($settings) {
  $output = "";
  if ($settings['border_width'] != "" && $settings['border_color'] != "") {
    $output = "border: {$settings['border_width']}px {$settings['border_style']} {$settings['border_color']}";
  }
  return $output;
}

/**
 * Generate custom spacing CSS.
 */
function _important_information_spacing_css($settings, $section_class) {
  $output = "";
  if ($settings['inner_spacing'] != "") {
    $output = "{$section_class} > h1 { padding: {$settings['inner_spacing']}px; }";
    $output .= "{$section_class} .information-body { padding: 0 {$settings['inner_spacing']}px {$settings['inner_spacing']}px; }";
  }
  return $output;
}

/**
 * Generate custom block body CSS.
 */
function _important_information_color_css($settings, $section_class) {
  $output = "";
  if ($settings['top_background_color'] != "") {
    $output = "$section_class .information-head { background-color: {$settings['top_background_color']}; }";
  }
  if ($settings['body_background_color'] != "") {
    $output .= "$section_class .information-body { background-color: {$settings['body_background_color']}; }";
  }
  return $output;
}

/**
 * Generate custom block body CSS.
 */
function _important_information_block_body_css($settings, $section_class) {
  $block_body_class = "$section_class .information-body";
  $block_body_styles = [];
  $output = "";
  if ($settings['body_font_color'] != "") {
    $block_body_styles['color'] = $settings['body_font_color'];
  }
  if ($settings['body_font_family'] != "") {
    $block_body_styles['font-family'] = $settings['body_font_family'];
  }
  if ($settings['body_font_size'] != "") {
    $block_body_styles['font-size'] = $settings['body_font_size'];
  }
  if (count($block_body_styles) > 0) {
    $block_body_styles = _important_information_rules_to_string($block_body_styles);
    $output = "$block_body_class { $block_body_styles }";
  }
  return $output;
}

/**
 * Generate custom headings CSS.
 */
function _important_information_headings_css($settings, $section_class) {
  $title_styles = [];
  $output = "";
  if ($settings['headings_color'] != "") {
    $title_styles['color'] = $settings['headings_color'];
  }
  if ($settings['headings_font_family'] != "") {
    $title_styles['font-family'] = $settings['headings_font_family'];
  }
  $main_title_style = _important_information_rules_to_string($title_styles + ['font-size' => $settings['headings_main_font_size']]);
  if ($main_title_style != "") {
    $output .= "$section_class h1 { $main_title_style }";
  }
  $secondary_title_style = _important_information_rules_to_string($title_styles + ['font-size' => $settings['headings_secondary_font_size']]);
  if ($secondary_title_style != "") {
    $output .= "$section_class h2 { $secondary_title_style }";
  }
  return $output;
}

/**
 * Generate custom positioning CSS.
 */
function _important_information_positioning_css($settings, $body_class, $section_class) {
  if ($settings['size'] == "") {
    return "";
  }
  // Positioning.
  $position_class = "$section_class.{$settings['position']}";
  $position_style = "";
  $body_margin_styles = "";
  $extra_styles = "";
  $button_position_styles = "";
  switch ($settings['position']) {
    case 'top':
      $position_style = "height: {$settings['size']};";
      if ($settings['outer_spacing'] > 0) {
        $spacing_total = $settings['outer_spacing'] * 2;
        $settings['size'] = "calc({$settings['size']} + {$spacing_total}px)";
        $position_style .= "width: calc(100% - {$spacing_total}px); left: {$settings['outer_spacing']}px; top: {$settings['outer_spacing']}px;";
        $extra_styles = ".block-important-information .action-links { right: {$settings['outer_spacing']}px; top: {$settings['outer_spacing']}px; margin-bottom: -{$settings['outer_spacing']}px; }";
      }
      if ($settings['body_spacing_type'] != "hidden") {
        $body_margin_styles = "$body_class > #page-wrapper { {$settings['body_spacing_type']}-top: {$settings['size']}; }";
        $body_margin_styles .= "$body_class > #overlay-container { height: calc(100% - {$settings['size']});top: {$settings['size']}; }";
      }
      break;

    case 'bottom':
      $position_style = "height: {$settings['size']};";
      if ($settings['outer_spacing'] > 0) {
        $spacing_total = $settings['outer_spacing'] * 2;
        $settings['size'] = "calc({$settings['size']} + {$spacing_total}px)";
        $position_style .= "width: calc(100% - {$spacing_total}px); left: {$settings['outer_spacing']}px; bottom: {$settings['outer_spacing']}px;";
        $extra_styles = ".block-important-information .action-links { right: {$settings['outer_spacing']}px; bottom: {$settings['size']}; margin-bottom: -{$settings['outer_spacing']}px; }";
      }
      if ($settings['body_spacing_type'] != "hidden") {
        $body_margin_styles = "$body_class > #page-wrapper { {$settings['body_spacing_type']}-bottom: {$settings['size']}; }";
        $body_margin_styles .= "$body_class > #overlay-container { height: calc(100% - {$settings['size']}); }";
      }
      $button_position_styles = "$body_class .important-information > .action-links { bottom: calc({$settings['size']} - 25px);top: auto; }";
      $button_position_styles .= "$body_class #block-important-information-important-information .contextual-links-wrapper { bottom: calc({$settings['size']} - 20px);top: auto; }";
      break;

    case 'right':
      $position_style = "width: {$settings['size']};";
      if ($settings['outer_spacing'] > 0) {
        $spacing_total = $settings['outer_spacing'] * 2;
        $settings['size'] = "calc({$settings['size']} + {$spacing_total}px)";
        $position_style .= "height: calc(100% - {$spacing_total}px); right: {$settings['outer_spacing']}px; top: {$settings['outer_spacing']}px;";
        $extra_styles = ".block-important-information .action-links { right: calc(16px + {$settings['outer_spacing']}px); }";
      }
      if ($settings['body_spacing_type'] != "hidden") {
        $body_margin_styles = "$body_class > #page-wrapper { {$settings['body_spacing_type']}-right: {$settings['size']}; }";
        $body_margin_styles .= "$body_class #toolbar { right: {$settings['size']}; margin: 0; padding: 0; }";
        $body_margin_styles .= "$body_class > #overlay-container { width: calc(100% - {$settings['size']}); }";
      }
      break;

    case 'left':
      $position_style = "width: {$settings['size']};";
      if ($settings['outer_spacing'] > 0) {
        $spacing_total = $settings['outer_spacing'] * 2;
        $settings['size'] = "calc({$settings['size']} + {$spacing_total}px)";
        $position_style .= "height: calc(100% - {$spacing_total}px); left: {$settings['outer_spacing']}px; top: {$settings['outer_spacing']}px;";
        $extra_styles = ".block-important-information .action-links { left: calc(16px + {$settings['outer_spacing']}px); }";
      }
      if ($settings['body_spacing_type'] != "hidden") {
        $body_margin_styles = "$body_class > #page-wrapper { {$settings['body_spacing_type']}-left: {$settings['size']}; }";
        $body_margin_styles .= "$body_class #toolbar { left: {$settings['size']}; margin: 0; padding: 0; }";
        $body_margin_styles .= "$body_class > #overlay-container { width: calc(100% - {$settings['size']});left: {$settings['size']}; }";
      }
      $button_position_styles = "$body_class .important-information > .action-links { left: calc({$settings['size']} - 40px);right: auto; }";
      $button_position_styles .= "$body_class #block-important-information-important-information .contextual-links-wrapper { left: calc({$settings['size']} - 75px);right: auto; }";
      break;

    case 'hidden':
      $body_margin_styles = "$body_class { margin: 0; }";
      $body_margin_styles .= "$body_class #page-wrapper { margin: 0; }";
      $position_style = "display: none;";
      break;

  }
  return <<<EOT
  $position_class { $position_style }
  $body_margin_styles
  $button_position_styles
  $extra_styles
EOT;
}

/**
 * Generate custom mobile positioning CSS.
 */
function _important_information_mobile_positioning_css($settings, $body_class, $section_class) {
  if ($settings['mobile_size'] == "") {
    return "";
  }
  // Positioning.
  $mobile_class = "@media (max-width: {$settings['mobile_breakpoint']}) { $body_class.mobile-ii-{$settings['mobile_position']} ";
  $position_class = "$mobile_class $section_class.{$settings['position']}";
  $position_style = "display: block;";
  $body_margin_styles = "";
  $button_position_styles = "";
  $mobile_styles = "";
  $extra_styles = $position_class;
  switch ($settings['mobile_position']) {
    case 'top':
      if ($settings['outer_spacing'] > 0) {
        $spacing_total = $settings['outer_spacing'] * 2;
        $settings['mobile_size'] = "calc({$settings['mobile_size']} + {$spacing_total}px)";
        $position_style .= "width: calc(100% - {$spacing_total}px); height: calc({$settings['mobile_size']} - {$spacing_total}px); top: {$settings['outer_spacing']}px; left: {$settings['outer_spacing']}px;";
        $extra_styles .= ".block-important-information .action-links { right: calc(16px + {$settings['outer_spacing']}px); } }";
      } else {
        $position_style .= "height: {$settings['mobile_size']}; }";
        $mobile_styles = "$position_class { top: 0; left: 0; width: 100%; bottom: auto; } }";
      }
      if ($settings['body_spacing_type'] != "hidden") {
        $body_margin_styles = "$mobile_class > #page-wrapper { {$settings['body_spacing_type']}-top: {$settings['mobile_size']}; } }";
        $body_margin_styles .= "$mobile_class > #overlay-container { height: calc(100% - {$settings['mobile_size']});top: {$settings['mobile_size']}; width: 100%; } }";
        $body_margin_styles .= "$mobile_class #toolbar { right: 0; left: 0; top: {$settings['mobile_size']}; } }";
      }
      $button_position_styles = "$mobile_class .important-information > .action-links { bottom: auto;top: auto; } }";
      $button_position_styles .= "$mobile_class #block-important-information-important-information .contextual-links-wrapper { bottom: auto;top: auto; } }";
      break;

    case 'bottom':
      if ($settings['outer_spacing'] > 0) {
        $spacing_total = $settings['outer_spacing'] * 2;
        $settings['mobile_size'] = "calc({$settings['mobile_size']} + {$spacing_total}px)";
        $position_style .= "width: calc(100% - {$spacing_total}px); height: calc({$settings['mobile_size']} - {$spacing_total}px); bottom: {$settings['outer_spacing']}px; left: {$settings['outer_spacing']}px;";
        $extra_styles .= ".block-important-information .action-links { right: calc(16px + {$settings['outer_spacing']}px); } }";
      } else {
        $position_style .= "height: {$settings['mobile_size']}; }";
        $mobile_styles = "$position_class { bottom: 0; left: 0; width: 100%; top: auto; } }";
      }
      if ($settings['body_spacing_type'] != "hidden") {
        $body_margin_styles = "$mobile_class > #page-wrapper { {$settings['body_spacing_type']}-bottom: {$settings['mobile_size']}; } }";
        $body_margin_styles .= "$mobile_class > #overlay-container { height: calc(100% - {$settings['mobile_size']}); width: 100%; top: {$settings['mobile_size']}; } }";
        $body_margin_styles .= "$mobile_class #toolbar { right: 0; left: 0; } }";
      }
      $button_position_styles = "$mobile_class .important-information > .action-links { bottom: calc({$settings['mobile_size']} - 25px);top: auto; } }";
      $button_position_styles .= "$mobile_class #block-important-information-important-information .contextual-links-wrapper { bottom: calc({$settings['mobile_size']} - 20px);top: auto; } }";
      break;

    case 'right':
      if ($settings['outer_spacing'] > 0) {
        $spacing_total = $settings['outer_spacing'] * 2;
        $settings['mobile_size'] = "calc({$settings['mobile_size']} + {$spacing_total}px)";
        $position_style .= "height: calc(100% - {$spacing_total}px); width: calc({$settings['mobile_size']} - {$spacing_total}px); top: {$settings['outer_spacing']}px; right: {$settings['outer_spacing']}px;";
        $extra_styles .= ".block-important-information .action-links { right: calc(16px + {$settings['outer_spacing']}px); } }";
      } else {
        $position_style .= "width: {$settings['mobile_size']}; }";
        $mobile_styles = "$position_class { top: 0; right: 0; height: 100%; } }";
      }
      if ($settings['body_spacing_type'] != "hidden") {
        $body_margin_styles = "$mobile_class { {$settings['body_spacing_type']}-right: {$settings['mobile_size']}; } }";
        $body_margin_styles .= "$mobile_class > #overlay-container { width: calc(100% - {$settings['mobile_size']}); height: 100%; right: {$settings['mobile_size']}; top: 0; } }";
        $body_margin_styles .= "$mobile_class #toolbar { right: {$settings['mobile_size']}; margin: 0; padding: 0; } }";
      }
      break;

    case 'left':
      if ($settings['outer_spacing'] > 0) {
        $spacing_total = $settings['outer_spacing'] * 2;
        $settings['mobile_size'] = "calc({$settings['mobile_size']} + {$spacing_total}px)";
        $position_style .= "height: calc(100% - {$spacing_total}px); width: calc({$settings['mobile_size']} - {$spacing_total}px); top: {$settings['outer_spacing']}px; left: {$settings['outer_spacing']}px;";
        $extra_styles .= ".block-important-information .action-links { left: calc(16px + {$settings['outer_spacing']}px); } }";
      } else {
        $position_style .= "width: {$settings['mobile_size']}; }";
        $mobile_styles = "$position_class { top: 0; right: 0; height: 100%; } }";
      }
      if ($settings['body_spacing_type'] != "hidden") {
        $body_margin_styles = "$mobile_class { {$settings['body_spacing_type']}-left: {$settings['mobile_size']}; } }";
        $body_margin_styles .= "$mobile_class > #overlay-container { width: calc(100% - {$settings['mobile_size']}); height: 100%; left: {$settings['mobile_size']}; } }";
        $body_margin_styles .= "$mobile_class #toolbar { left: {$settings['mobile_size']}; margin: 0; padding: 0; } }";
      }
      break;

    case 'hidden':
      $position_style = "display: none; }";
      $body_margin_styles = "$mobile_class { margin: 0; } }";
      $body_margin_styles .= "$mobile_class #page-wrapper { margin: 0; } }";
      break;

  }
  return <<<EOT
  $position_class { $position_style }
  $body_margin_styles
  $button_position_styles
  $mobile_styles
  $extra_styles
EOT;
}

/**
 * Turn an array into a stringified set of CSS properties.
 */
function _important_information_rules_to_string($rules) {
  $output = "";
  foreach ($rules as $key => $rule) {
    if ($rule != "") {
      $output .= "$key: $rule;";
    }
  }
  return $output;
}
